<?php
if (!isset($gCms)) exit;
$db =& $gCms->GetDb();
$taboptarray = array( 'mysql' => 'TYPE=MyISAM' );
$dict = NewDataDictionary( $db );
$flds = "
         tree_id I KEY,
	 alias C(80),
	 description C(255),
	 max_depth I,
	 template X,
         allow_decision_wysiwyg I1
";
$sqlarray = $dict->CreateTableSQL( cms_db_prefix()."module_dectree_trees",
				   $flds, 
				   $taboptarray);
$dict->ExecuteSQLArray($sqlarray);
$db->CreateSequence(cms_db_prefix()."module_dectree_trees_seq");

$flds = "
         decision_id I KEY,
         tree_id I,
		 parent_id I,
		 is_result I,
	 	 decision X,
		 returns X,
	     alternate X,
	     prompt C(255),
	     suggestion X,
 	     order_by I
";
$sqlarray = $dict->CreateTableSQL( cms_db_prefix()."module_dectree_decs",
				   $flds, 
				   $taboptarray);
$dict->ExecuteSQLArray($sqlarray);
$db->Execute('create index '.cms_db_prefix().'module_dectree_dec_idx on '.cms_db_prefix().'module_dectree_decs (tree_id,parent_id)');

$db->CreateSequence(cms_db_prefix()."module_dectree_decs_seq");

$template = file_get_contents(dirname(__FILE__).'/templates/stdtree.tpl');
$this->SetPreference('default_template',$template);

// put mention into the admin log
$this->Audit( 0, 
	      $this->Lang('friendlyname'), 
	      $this->Lang('installed', $this->GetVersion()) );

	      
?>